@@ -1,5 +1,6 @@
 from UnleashClient.strategies import ApplicationHostname, Default, GradualRolloutRandom, \
     GradualRolloutSessionId, GradualRolloutUserId, UserWithId, RemoteAddress, FlexibleRollout
+from UnleashClient.constants import FEATURES_URL
 
 # General configs
 APP_NAME = "pytest"
@@ -15,9 +16,11 @@ CUSTOM_OPTIONS = {"verify": False}
 # URLs
 URL = "http://localhost:4242/api"
 INTEGRATION_URL = "http://localhost:4242/api"
+PROJECT_URL = f"{URL}{FEATURES_URL}?project=ivan"
 
 # Constants
 IP_LIST = "69.208.0.0/29,70.208.1.1,2001:db8:1234::/48,2002:db8:1234:0000:0000:0000:0000:0001"
+PROJECT_NAME = 'ivan'
 
 # Mapping
 DEFAULT_STRATEGY_MAPPING = {
